@@ -24,7 +24,12 @@ class TestSerialize(TestCase):
             owner=Person(name="Fred"),
         )
 
-        expected_serializer_data = {"name": "Garfield", "toys": "paper ball, string"}
+        expected_serializer_data = {
+            "name": "Garfield",
+            "toys": "paper ball, string",
+            "diet": "",
+            "sold_from": None,
+        }
 
         serializer = PetSerializer(pet, omit=["species", "owner"])
         self.assertEqual(serializer.data, expected_serializer_data)
@@ -41,15 +46,18 @@ class TestSerialize(TestCase):
         )
 
         expected_serializer_data = {
+            "diet": "",
             "name": "Garfield",
             "toys": "paper ball, string",
             "species": "cat",
             "owner": {"hobbies": "", "employer": {"name": "McDonalds"}},
+            "sold_from": None,
         }
 
         serializer = PetSerializer(
             pet, expand=["owner.employer"], omit=["owner.name", "owner.employer.public"]
         )
+
         self.assertEqual(serializer.data, expected_serializer_data)
 
         serializer = PetSerializer(
@@ -85,9 +93,7 @@ class TestSerialize(TestCase):
 
         expected_serializer_data = {"owner": {"employer": {"name": "McDonalds"}}}
 
-        serializer = PetSerializer(
-            pet, expand=["owner.employer"], fields=["owner.employer.name"]
-        )
+        serializer = PetSerializer(pet, expand=["owner.employer"], fields=["owner.employer.name"])
         self.assertEqual(serializer.data, expected_serializer_data)
 
         serializer = PetSerializer(
@@ -110,6 +116,8 @@ class TestSerialize(TestCase):
             "toys": "paper ball, string",
             "species": "cat",
             "owner": {"name": "Fred", "hobbies": "sailing"},
+            "sold_from": None,
+            "diet": "",
         }
 
         request = MockRequest(query_params=MultiValueDict({"expand": ["owner"]}))
@@ -125,12 +133,11 @@ class TestSerialize(TestCase):
             name="Garfield",
             toys="paper ball, string",
             species="cat",
-            owner=Person(
-                name="Fred", hobbies="sailing", employer=Company(name="McDonalds")
-            ),
+            owner=Person(name="Fred", hobbies="sailing", employer=Company(name="McDonalds")),
         )
 
         expected_serializer_data = {
+            "diet": "",
             "name": "Garfield",
             "toys": "paper ball, string",
             "species": "cat",
@@ -139,11 +146,10 @@ class TestSerialize(TestCase):
                 "hobbies": "sailing",
                 "employer": {"public": False, "name": "McDonalds"},
             },
+            "sold_from": None,
         }
 
-        request = MockRequest(
-            query_params=MultiValueDict({"expand": ["owner.employer"]})
-        )
+        request = MockRequest(query_params=MultiValueDict({"expand": ["owner.employer"]}))
         serializer = PetSerializer(pet, context={"request": request})
         self.assertEqual(serializer.data, expected_serializer_data)
         self.assertEqual(
@@ -159,22 +165,20 @@ class TestSerialize(TestCase):
             name="Garfield",
             toys="paper ball, string",
             species="cat",
-            owner=Person(
-                name="Fred", hobbies="sailing", employer=Company(name="McDonalds")
-            ),
+            owner=Person(name="Fred", hobbies="sailing", employer=Company(name="McDonalds")),
         )
 
-        request = MockRequest(
-            query_params=MultiValueDict({"expand": ["owner.employer"]})
-        )
+        request = MockRequest(query_params=MultiValueDict({"expand": ["owner.employer"]}))
         serializer = PetSerializer(pet, context={"request": request})
 
         self.assertEqual(
             serializer.data,
             {
+                "diet": "",
                 "name": "Garfield",
                 "toys": "paper ball, string",
                 "species": "cat",
+                "sold_from": None,
                 "owner": {
                     "name": "Fred",
                     "hobbies": "sailing",
@@ -193,10 +197,12 @@ class TestSerialize(TestCase):
         )
 
         expected_serializer_data = {
+            "diet": "",
             "name": "Garfield",
             "toys": "paper ball, string",
             "species": "cat",
             "owner": {"name": "Fred", "hobbies": "sailing"},
+            "sold_from": None,
         }
 
         serializer = PetSerializer(pet, include=["owner"])
@@ -211,7 +217,12 @@ class TestSerialize(TestCase):
             owner=Person(name="Fred"),
         )
 
-        expected_serializer_data = {"name": "Garfield", "toys": "paper ball, string"}
+        expected_serializer_data = {
+            "name": "Garfield",
+            "toys": "paper ball, string",
+            "diet": "",
+            "sold_from": None,
+        }
 
         serializer = PetSerializer(pet, exclude=["species", "owner"])
         self.assertEqual(serializer.data, expected_serializer_data)
@@ -254,6 +265,7 @@ class TestSerialize(TestCase):
                 "toys": "paper ball",
                 "species": "cat",
                 "owner": None,
+                "diet": "lasanga",
             },
         )
 
